from django.contrib import messages
from django.contrib.auth.decorators import login_required
from django.shortcuts import render, redirect
from django.utils.decorators import method_decorator
from django.views import View

from customers.forms import ProfileForm, form_validation_error
from customers.models import Profile
from django.contrib.auth.models import User


@method_decorator(login_required(login_url='login'), name='dispatch')
class ProfileView(View):
    profile = None

    def dispatch(self, request, *args, **kwargs):
        self.profile, __ = Profile.objects.get_or_create(user=request.user)
        return super(ProfileView, self).dispatch(request, *args, **kwargs)

    def get(self, request):
        context = {'profile': self.profile, 'segment': 'profile'}
        return render(request, 'customers/profile.html', context)

    def post(self, request):
        form = ProfileForm(request.POST, request.FILES, instance=self.profile)

        if form.is_valid():
            profile = form.save()
            profile.user.first_name = form.cleaned_data.get('first_name')
            profile.user.last_name = form.cleaned_data.get('last_name')
            profile.user.email = form.cleaned_data.get('email')
            profile.user.save()

            messages.success(request, 'Profile saved successfully')
        else:
            messages.error(request, form_validation_error(form))
        return redirect('profile')

@login_required(login_url="/login/")
def changer_mot_de_passe(request):
    if request.method == 'POST':
        username = request.POST.get('username')
        password1 = request.POST.get('password1')
        password2 = request.POST.get('password2')
        print("*******", username)
        u = None
    try:
        u = User.objects.get(username=username)
    except Exception as e:
        messages.error(request, "L'utilisateur ou les mots de passes ne sont pas valide")
        return render(request, 'reset-password.html',{})
    
    if u is not None and password1== password2 :

        try:
            u.set_password(password1)
            u.save()
            messages.success(request, 'Vous avez changez votre mot de passe reconnectez-Vous!')
            redirect('logout')  
        except Exception as e:
            print(e)
            messages.error(request, "Le mot de passe est faible")
            return render(request, 'reset-password.html',{}) 
        
        
        
    else:
        messages.error(request, "L'utilisateur ou les mots de passes ne sont pas valide")
        return render(request, 'reset-password.html',{})

    return render(request, 'reset-password.html',{}) 


    
